==> messaging-5.16.0-sources.jar: com/liveperson/messaging/model/NullMessagesListener.java <==
package com.liveperson.messaging.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by shiranr on 3/30/17.
 */

public class NullMessagesListener implements AmsMessages.MessagesListener {
    @Override
    public void initMessages(ArrayList<FullMessageRow> searchedMessageList) {

    }

    @Override
    public void onQueryMessagesResult(long firstTimestamp, long lastTimestamp) {

    }

    @Override
    public void onUpdateMessages(long firstTimestamp, long lastTimestamp) {

    }

    @Override
    public void onNewMessage(FullMessageRow fullMessageRow) {

    }

    @Override
    public void onUpdateMessage(FullMessageRow fullMessageRow) {

    }

    @Override
    public void onUpdateFileMessage(String eventId, long localId, FileMessage fullMessageRow) {

    }

    @Override
    public void onInitialMessagesReceived(List<FullMessageRow> rows) {

    }

    @Override
    public void removeAllClosedConversations(String targetId) {

    }

    @Override
    public void clearAllMessages(String targetId) {

    }

    @Override
    public void onHistoryFetched() {

    }

    @Override
    public void onExConversationHandled(boolean emptyNotification) {

    }

    @Override
    public void onHistoryFetchedFailed() {

    }

    @Override
    public void addFirstWelcomeMessage() {

    }

    @Override
    public void onAgentReceived(MessagingUserProfile userProfile) {

    }

    @Override
    public int getLoadLimit() {
        return 0;
    }

    @Override
    public void showErrorToast(int messageRes) { }
}

==> messaging-5.19.0-sources.jar: com/liveperson/messaging/model/NullMessagesListener.java <==
package com.liveperson.messaging.model;

import androidx.annotation.NonNull;

import com.liveperson.infra.model.LPWelcomeMessage;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by shiranr on 3/30/17.
 */

public class NullMessagesListener implements AmsMessages.MessagesListener {
    @Override
    public void initMessages(ArrayList<FullMessageRow> searchedMessageList) {

    }

    @Override
    public void onQueryMessagesResult(long firstTimestamp, long lastTimestamp) {

    }

    @Override
    public void onUpdateMessages(long firstTimestamp, long lastTimestamp) {

    }

    @Override
    public void onNewMessage(FullMessageRow fullMessageRow) {

    }

    @Override
    public void onNewWelcomeMessage(@NonNull FullMessageRow row, @NonNull LPWelcomeMessage welcomeMessage, @NonNull OnWelcomeMessageShownCallback callback) {

    }

    @Override
    public void onUpdateMessage(FullMessageRow fullMessageRow) {

    }

    @Override
    public void onUpdateFileMessage(String eventId, long localId, FileMessage fullMessageRow) {

    }

    @Override
    public void onInitialMessagesReceived(List<FullMessageRow> rows) {

    }

    @Override
    public void removeAllClosedConversations(String targetId) {

    }

    @Override
    public void clearAllMessages(String targetId) {

    }

    @Override
    public void onHistoryFetched() {

    }

    @Override
    public void onExConversationHandled(boolean emptyNotification) {

    }

    @Override
    public void onHistoryFetchedFailed() {

    }

    @Override
    public void addFirstWelcomeMessage() {

    }

    @Override
    public void onAgentReceived(MessagingUserProfile userProfile) {

    }

    @Override
    public int getLoadLimit() {
        return 0;
    }

    @Override
    public void showErrorToast(int messageRes) { }

    @Override
    public void updateWelcomeMessageForDialogId(String dialogId, FullMessageRow welcomeMessageRow) {

    }

    @Override
    public void updateTempWelcomeMessage(FullMessageRow welcomeMessageRow) {

    }
}
